# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/areas_of_interest_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/areas_of_interest_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n0fsai_grpc_api/protos/areas_of_interest_api.proto\x1a fsai_grpc_api/protos/utils.proto\"L\n\x0e\x41reaOfInterest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x12\n\nmission_id\x18\x02 \x01(\x05\x12\x1a\n\x08geo_bbox\x18\x03 \x01(\x0b\x32\x08.GeoBbox\"N\n!FindOrCreateAreaOfInterestRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"q\n\"FindOrCreateAreaOfInterestResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"O\n\"UpdateAreaOfInterestGeoBboxRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"r\n#UpdateAreaOfInterestGeoBboxResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12)\n\x10\x61rea_of_interest\x18\x02 \x01(\x0b\x32\x0f.AreaOfInterest\"L\n\x1f\x44\x65leteAreaOfInterestByIdRequest\x12)\n\x10\x61rea_of_interest\x18\x01 \x01(\x0b\x32\x0f.AreaOfInterest\"D\n DeleteAreaOfInterestByIdResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType2\xc6\x02\n\x12\x41reasOfInterestApi\x12\x65\n\x1a\x46indOrCreateAreaOfInterest\x12\".FindOrCreateAreaOfInterestRequest\x1a#.FindOrCreateAreaOfInterestResponse\x12h\n\x1bUpdateAreaOfInterestGeoBbox\x12#.UpdateAreaOfInterestGeoBboxRequest\x1a$.UpdateAreaOfInterestGeoBboxResponse\x12_\n\x18\x44\x65leteAreaOfInterestById\x12 .DeleteAreaOfInterestByIdRequest\x1a!.DeleteAreaOfInterestByIdResponseb\x06proto3'
  ,
  dependencies=[fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_AREAOFINTEREST = _descriptor.Descriptor(
  name='AreaOfInterest',
  full_name='AreaOfInterest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='AreaOfInterest.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission_id', full_name='AreaOfInterest.mission_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='geo_bbox', full_name='AreaOfInterest.geo_bbox', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=162,
)


_FINDORCREATEAREAOFINTERESTREQUEST = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestRequest',
  full_name='FindOrCreateAreaOfInterestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=242,
)


_FINDORCREATEAREAOFINTERESTRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateAreaOfInterestResponse',
  full_name='FindOrCreateAreaOfInterestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateAreaOfInterestResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='FindOrCreateAreaOfInterestResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=357,
)


_UPDATEAREAOFINTERESTGEOBBOXREQUEST = _descriptor.Descriptor(
  name='UpdateAreaOfInterestGeoBboxRequest',
  full_name='UpdateAreaOfInterestGeoBboxRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestGeoBboxRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=359,
  serialized_end=438,
)


_UPDATEAREAOFINTERESTGEOBBOXRESPONSE = _descriptor.Descriptor(
  name='UpdateAreaOfInterestGeoBboxResponse',
  full_name='UpdateAreaOfInterestGeoBboxResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='UpdateAreaOfInterestGeoBboxResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='UpdateAreaOfInterestGeoBboxResponse.area_of_interest', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=554,
)


_DELETEAREAOFINTERESTBYIDREQUEST = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdRequest',
  full_name='DeleteAreaOfInterestByIdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='area_of_interest', full_name='DeleteAreaOfInterestByIdRequest.area_of_interest', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=556,
  serialized_end=632,
)


_DELETEAREAOFINTERESTBYIDRESPONSE = _descriptor.Descriptor(
  name='DeleteAreaOfInterestByIdResponse',
  full_name='DeleteAreaOfInterestByIdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='DeleteAreaOfInterestByIdResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=702,
)

_AREAOFINTEREST.fields_by_name['geo_bbox'].message_type = fsai__grpc__api_dot_protos_dot_utils__pb2._GEOBBOX
_FINDORCREATEAREAOFINTERESTREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEAREAOFINTERESTRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTGEOBBOXREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_UPDATEAREAOFINTERESTGEOBBOXRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_UPDATEAREAOFINTERESTGEOBBOXRESPONSE.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDREQUEST.fields_by_name['area_of_interest'].message_type = _AREAOFINTEREST
_DELETEAREAOFINTERESTBYIDRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
DESCRIPTOR.message_types_by_name['AreaOfInterest'] = _AREAOFINTEREST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestRequest'] = _FINDORCREATEAREAOFINTERESTREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateAreaOfInterestResponse'] = _FINDORCREATEAREAOFINTERESTRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestGeoBboxRequest'] = _UPDATEAREAOFINTERESTGEOBBOXREQUEST
DESCRIPTOR.message_types_by_name['UpdateAreaOfInterestGeoBboxResponse'] = _UPDATEAREAOFINTERESTGEOBBOXRESPONSE
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdRequest'] = _DELETEAREAOFINTERESTBYIDREQUEST
DESCRIPTOR.message_types_by_name['DeleteAreaOfInterestByIdResponse'] = _DELETEAREAOFINTERESTBYIDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AreaOfInterest = _reflection.GeneratedProtocolMessageType('AreaOfInterest', (_message.Message,), {
  'DESCRIPTOR' : _AREAOFINTEREST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:AreaOfInterest)
  })
_sym_db.RegisterMessage(AreaOfInterest)

FindOrCreateAreaOfInterestRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestRequest)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestRequest)

FindOrCreateAreaOfInterestResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateAreaOfInterestResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEAREAOFINTERESTRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateAreaOfInterestResponse)
  })
_sym_db.RegisterMessage(FindOrCreateAreaOfInterestResponse)

UpdateAreaOfInterestGeoBboxRequest = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestGeoBboxRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTGEOBBOXREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestGeoBboxRequest)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestGeoBboxRequest)

UpdateAreaOfInterestGeoBboxResponse = _reflection.GeneratedProtocolMessageType('UpdateAreaOfInterestGeoBboxResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAREAOFINTERESTGEOBBOXRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:UpdateAreaOfInterestGeoBboxResponse)
  })
_sym_db.RegisterMessage(UpdateAreaOfInterestGeoBboxResponse)

DeleteAreaOfInterestByIdRequest = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDREQUEST,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdRequest)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdRequest)

DeleteAreaOfInterestByIdResponse = _reflection.GeneratedProtocolMessageType('DeleteAreaOfInterestByIdResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAREAOFINTERESTBYIDRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.areas_of_interest_api_pb2'
  # @@protoc_insertion_point(class_scope:DeleteAreaOfInterestByIdResponse)
  })
_sym_db.RegisterMessage(DeleteAreaOfInterestByIdResponse)



_AREASOFINTERESTAPI = _descriptor.ServiceDescriptor(
  name='AreasOfInterestApi',
  full_name='AreasOfInterestApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=705,
  serialized_end=1031,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateAreaOfInterest',
    full_name='AreasOfInterestApi.FindOrCreateAreaOfInterest',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEAREAOFINTERESTREQUEST,
    output_type=_FINDORCREATEAREAOFINTERESTRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateAreaOfInterestGeoBbox',
    full_name='AreasOfInterestApi.UpdateAreaOfInterestGeoBbox',
    index=1,
    containing_service=None,
    input_type=_UPDATEAREAOFINTERESTGEOBBOXREQUEST,
    output_type=_UPDATEAREAOFINTERESTGEOBBOXRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteAreaOfInterestById',
    full_name='AreasOfInterestApi.DeleteAreaOfInterestById',
    index=2,
    containing_service=None,
    input_type=_DELETEAREAOFINTERESTBYIDREQUEST,
    output_type=_DELETEAREAOFINTERESTBYIDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_AREASOFINTERESTAPI)

DESCRIPTOR.services_by_name['AreasOfInterestApi'] = _AREASOFINTERESTAPI

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from fsai_grpc_api.protos import areas_of_interest_api_pb2 as fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2


class AreasOfInterestApiStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.FindOrCreateAreaOfInterest = channel.unary_unary(
                '/AreasOfInterestApi/FindOrCreateAreaOfInterest',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
                )
        self.UpdateAreaOfInterestGeoBbox = channel.unary_unary(
                '/AreasOfInterestApi/UpdateAreaOfInterestGeoBbox',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.FromString,
                )
        self.DeleteAreaOfInterestById = channel.unary_unary(
                '/AreasOfInterestApi/DeleteAreaOfInterestById',
                request_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
                response_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
                )


class AreasOfInterestApiServicer(object):
    """Missing associated documentation comment in .proto file."""

    def FindOrCreateAreaOfInterest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAreaOfInterestGeoBbox(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAreaOfInterestById(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AreasOfInterestApiServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'FindOrCreateAreaOfInterest': grpc.unary_unary_rpc_method_handler(
                    servicer.FindOrCreateAreaOfInterest,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.SerializeToString,
            ),
            'UpdateAreaOfInterestGeoBbox': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAreaOfInterestGeoBbox,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.SerializeToString,
            ),
            'DeleteAreaOfInterestById': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAreaOfInterestById,
                    request_deserializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.FromString,
                    response_serializer=fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AreasOfInterestApi', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AreasOfInterestApi(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def FindOrCreateAreaOfInterest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/FindOrCreateAreaOfInterest',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.FindOrCreateAreaOfInterestResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAreaOfInterestGeoBbox(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/UpdateAreaOfInterestGeoBbox',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.UpdateAreaOfInterestGeoBboxResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAreaOfInterestById(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AreasOfInterestApi/DeleteAreaOfInterestById',
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdRequest.SerializeToString,
            fsai__grpc__api_dot_protos_dot_areas__of__interest__api__pb2.DeleteAreaOfInterestByIdResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/utils.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/utils.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n fsai_grpc_api/protos/utils.proto\"M\n\x07GeoBbox\x12\x0f\n\x07min_lat\x18\x01 \x01(\x02\x12\x0f\n\x07max_lat\x18\x02 \x01(\x02\x12\x0f\n\x07min_lon\x18\x03 \x01(\x02\x12\x0f\n\x07max_lon\x18\x04 \x01(\x02\"$\n\x08GeoPoint\x12\x0b\n\x03lat\x18\x01 \x01(\x02\x12\x0b\n\x03lon\x18\x02 \x01(\x02*q\n\nChangeType\x12\x17\n\x13UNKNOWN_CHANGE_TYPE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x08\n\x04READ\x10\x02\x12\x0b\n\x07UPDATED\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\x12\n\n\x06\x45XISTS\x10\x05\x12\r\n\tNOT_FOUND\x10\x06\x62\x06proto3'
)

_CHANGETYPE = _descriptor.EnumDescriptor(
  name='ChangeType',
  full_name='ChangeType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_CHANGE_TYPE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CREATED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UPDATED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DELETED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXISTS', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_FOUND', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=266,
)
_sym_db.RegisterEnumDescriptor(_CHANGETYPE)

ChangeType = enum_type_wrapper.EnumTypeWrapper(_CHANGETYPE)
UNKNOWN_CHANGE_TYPE = 0
CREATED = 1
READ = 2
UPDATED = 3
DELETED = 4
EXISTS = 5
NOT_FOUND = 6



_GEOBBOX = _descriptor.Descriptor(
  name='GeoBbox',
  full_name='GeoBbox',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_lat', full_name='GeoBbox.min_lat', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lat', full_name='GeoBbox.max_lat', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lon', full_name='GeoBbox.min_lon', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lon', full_name='GeoBbox.max_lon', index=3,
      number=4, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=36,
  serialized_end=113,
)


_GEOPOINT = _descriptor.Descriptor(
  name='GeoPoint',
  full_name='GeoPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat', full_name='GeoPoint.lat', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lon', full_name='GeoPoint.lon', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=115,
  serialized_end=151,
)

DESCRIPTOR.message_types_by_name['GeoBbox'] = _GEOBBOX
DESCRIPTOR.message_types_by_name['GeoPoint'] = _GEOPOINT
DESCRIPTOR.enum_types_by_name['ChangeType'] = _CHANGETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GeoBbox = _reflection.GeneratedProtocolMessageType('GeoBbox', (_message.Message,), {
  'DESCRIPTOR' : _GEOBBOX,
  '__module__' : 'fsai_grpc_api.protos.utils_pb2'
  # @@protoc_insertion_point(class_scope:GeoBbox)
  })
_sym_db.RegisterMessage(GeoBbox)

GeoPoint = _reflection.GeneratedProtocolMessageType('GeoPoint', (_message.Message,), {
  'DESCRIPTOR' : _GEOPOINT,
  '__module__' : 'fsai_grpc_api.protos.utils_pb2'
  # @@protoc_insertion_point(class_scope:GeoPoint)
  })
_sym_db.RegisterMessage(GeoPoint)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/mission_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='fsai_grpc_api/protos/mission_api.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&fsai_grpc_api/protos/mission_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"S\n\x07Mission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"7\n\x1a\x46indOrCreateMissionRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"Z\n\x1b\x46indOrCreateMissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x19\n\x07mission\x18\x02 \x01(\x0b\x32\x08.Mission\"0\n\x13ListMissionsRequest\x12\x19\n\x07mission\x18\x01 \x01(\x0b\x32\x08.Mission\"T\n\x14ListMissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1a\n\x08missions\x18\x02 \x03(\x0b\x32\x08.Mission2\x9b\x01\n\nMissionApi\x12P\n\x13\x46indOrCreateMission\x12\x1b.FindOrCreateMissionRequest\x1a\x1c.FindOrCreateMissionResponse\x12;\n\x0cListMissions\x12\x14.ListMissionsRequest\x1a\x15.ListMissionsResponseb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,fsai__grpc__api_dot_protos_dot_utils__pb2.DESCRIPTOR,])




_MISSION = _descriptor.Descriptor(
  name='Mission',
  full_name='Mission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Mission.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='Mission.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='Mission.created_at', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=109,
  serialized_end=192,
)


_FINDORCREATEMISSIONREQUEST = _descriptor.Descriptor(
  name='FindOrCreateMissionRequest',
  full_name='FindOrCreateMissionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindOrCreateMissionRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=249,
)


_FINDORCREATEMISSIONRESPONSE = _descriptor.Descriptor(
  name='FindOrCreateMissionResponse',
  full_name='FindOrCreateMissionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='FindOrCreateMissionResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mission', full_name='FindOrCreateMissionResponse.mission', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=341,
)


_LISTMISSIONSREQUEST = _descriptor.Descriptor(
  name='ListMissionsRequest',
  full_name='ListMissionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mission', full_name='ListMissionsRequest.mission', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=343,
  serialized_end=391,
)


_LISTMISSIONSRESPONSE = _descriptor.Descriptor(
  name='ListMissionsResponse',
  full_name='ListMissionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='change_type', full_name='ListMissionsResponse.change_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='missions', full_name='ListMissionsResponse.missions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=477,
)

_MISSION.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FINDORCREATEMISSIONREQUEST.fields_by_name['mission'].message_type = _MISSION
_FINDORCREATEMISSIONRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_FINDORCREATEMISSIONRESPONSE.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSREQUEST.fields_by_name['mission'].message_type = _MISSION
_LISTMISSIONSRESPONSE.fields_by_name['change_type'].enum_type = fsai__grpc__api_dot_protos_dot_utils__pb2._CHANGETYPE
_LISTMISSIONSRESPONSE.fields_by_name['missions'].message_type = _MISSION
DESCRIPTOR.message_types_by_name['Mission'] = _MISSION
DESCRIPTOR.message_types_by_name['FindOrCreateMissionRequest'] = _FINDORCREATEMISSIONREQUEST
DESCRIPTOR.message_types_by_name['FindOrCreateMissionResponse'] = _FINDORCREATEMISSIONRESPONSE
DESCRIPTOR.message_types_by_name['ListMissionsRequest'] = _LISTMISSIONSREQUEST
DESCRIPTOR.message_types_by_name['ListMissionsResponse'] = _LISTMISSIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Mission = _reflection.GeneratedProtocolMessageType('Mission', (_message.Message,), {
  'DESCRIPTOR' : _MISSION,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:Mission)
  })
_sym_db.RegisterMessage(Mission)

FindOrCreateMissionRequest = _reflection.GeneratedProtocolMessageType('FindOrCreateMissionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEMISSIONREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateMissionRequest)
  })
_sym_db.RegisterMessage(FindOrCreateMissionRequest)

FindOrCreateMissionResponse = _reflection.GeneratedProtocolMessageType('FindOrCreateMissionResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINDORCREATEMISSIONRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:FindOrCreateMissionResponse)
  })
_sym_db.RegisterMessage(FindOrCreateMissionResponse)

ListMissionsRequest = _reflection.GeneratedProtocolMessageType('ListMissionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSREQUEST,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsRequest)
  })
_sym_db.RegisterMessage(ListMissionsRequest)

ListMissionsResponse = _reflection.GeneratedProtocolMessageType('ListMissionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMISSIONSRESPONSE,
  '__module__' : 'fsai_grpc_api.protos.mission_api_pb2'
  # @@protoc_insertion_point(class_scope:ListMissionsResponse)
  })
_sym_db.RegisterMessage(ListMissionsResponse)



_MISSIONAPI = _descriptor.ServiceDescriptor(
  name='MissionApi',
  full_name='MissionApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=480,
  serialized_end=635,
  methods=[
  _descriptor.MethodDescriptor(
    name='FindOrCreateMission',
    full_name='MissionApi.FindOrCreateMission',
    index=0,
    containing_service=None,
    input_type=_FINDORCREATEMISSIONREQUEST,
    output_type=_FINDORCREATEMISSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListMissions',
    full_name='MissionApi.ListMissions',
    index=1,
    containing_service=None,
    input_type=_LISTMISSIONSREQUEST,
    output_type=_LISTMISSIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MISSIONAPI)

DESCRIPTOR.services_by_name['MissionApi'] = _MISSIONAPI

# @@protoc_insertion_point(module_scope)
